==> haskell-http-api-data-0.4.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.4.1
id: http-api-data-0.4.1-7ro4mJoKcbz17DitSV2R99
key: http-api-data-0.4.1-7ro4mJoKcbz17DitSV2R99
license: BSD-3-Clause
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.
    .
    Please see README.md
category: Web
abi: 7de16b0eb4b3338ce12e636f667068c0
exposed: True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-api-data-0.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-api-data-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-api-data-0.4.1
hs-libraries: HShttp-api-data-0.4.1-7ro4mJoKcbz17DitSV2R99
depends:
    attoparsec-0.13.2.2-DdvIu9rGyq0BlJd07CKvqt
    attoparsec-iso8601-1.0.1.0-GzKjFGM9tXGGF9nB2ZgyfG base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-types-0.12.3-DjUfJGJk6hCCTTHJ6nQhEX
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    time-compat-1.9.2.2-HNNynysqEz1JQFo2XfT66A
    unordered-containers-0.2.10.0-DuDkJMfSb9t61flNcUovL1
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.4.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.4.1
id: http-api-data-0.4.1-24gDk8mVmZmEhHsrhXyVOb
key: http-api-data-0.4.1-24gDk8mVmZmEhHsrhXyVOb
license: BSD-3-Clause
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.
    .
    Please see README.md
category: Web
abi: 53ead048d1b0512f6c3f61c83c54e995
exposed: True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-api-data-0.4.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-api-data-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-api-data-0.4.1
hs-libraries: HShttp-api-data-0.4.1-24gDk8mVmZmEhHsrhXyVOb
depends:
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t
    attoparsec-iso8601-1.0.1.0-3psXVkbPM97GRGfBeP1f9U base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    containers-0.6.0.1 cookie-0.4.4-BFYr3M2B0n8F3gqLxXgKNx
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP text-1.2.3.1
    time-compat-1.9.2.2-LEycyZCy3wu2PetPD3qhd5
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    uuid-types-1.0.3-1r1IBIU9fBZK1eE2MZEQJb
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
